@@ -1,16 +1,17 @@
 """
-Rate limiting utilities
+Rate limiting with commonly used storage backends
 """
-from ._version import get_versions
 
+from . import aio, storage, strategies
+from ._version import get_versions
 from .limits import (
     RateLimitItem,
-    RateLimitItemPerYear,
-    RateLimitItemPerMonth,
     RateLimitItemPerDay,
     RateLimitItemPerHour,
     RateLimitItemPerMinute,
+    RateLimitItemPerMonth,
     RateLimitItemPerSecond,
+    RateLimitItemPerYear,
 )
 from .util import parse, parse_many
 
@@ -25,6 +26,9 @@ __all__ = [
     "RateLimitItemPerHour",
     "RateLimitItemPerMinute",
     "RateLimitItemPerSecond",
+    "aio",
+    "storage",
+    "strategies",
     "parse",
     "parse_many",
 ]
