@@ -55,7 +55,9 @@ class MemoryStorage(Storage, MovingWindowSupport):
         if not self.timer or self.timer.done():
             self.timer = asyncio.create_task(self.__expire_events())
 
-    async def incr(self, key: str, expiry: int, elastic_expiry: bool = False) -> int:
+    async def incr(
+        self, key: str, expiry: int, elastic_expiry: bool = False, amount: int = 1
+    ) -> int:
         """
         increments the counter for a given rate limit key
 
@@ -63,15 +65,16 @@ class MemoryStorage(Storage, MovingWindowSupport):
         :param expiry: amount in seconds for the key to expire in
         :param elastic_expiry: whether to keep extending the rate limit
          window every hit.
+        :param amount: the number to increment by
         """
         await self.get(key)
         await self.__schedule_expiry()
-        self.storage[key] += 1
+        self.storage[key] += amount
 
-        if elastic_expiry or self.storage[key] == 1:
+        if elastic_expiry or self.storage[key] == amount:
             self.expirations[key] = time.time() + expiry
 
-        return self.storage.get(key, 0)
+        return self.storage.get(key, amount)
 
     async def get(self, key: str) -> int:
         """
@@ -92,24 +95,27 @@ class MemoryStorage(Storage, MovingWindowSupport):
         self.expirations.pop(key, None)
         self.events.pop(key, None)
 
-    async def acquire_entry(self, key: str, limit: int, expiry: int) -> bool:
+    async def acquire_entry(
+        self, key: str, limit: int, expiry: int, amount: int = 1
+    ) -> bool:
         """
         :param key: rate limit key to acquire an entry in
         :param limit: amount of entries allowed
         :param expiry: expiry of the entry
+        :param amount: the number of entries to acquire
         """
         self.events.setdefault(key, [])
         await self.__schedule_expiry()
         timestamp = time.time()
         try:
-            entry: Optional[LockableEntry] = self.events[key][limit - 1]
+            entry: Optional[LockableEntry] = self.events[key][limit - amount]
         except IndexError:
             entry = None
 
         if entry and entry.atime >= timestamp - expiry:
             return False
         else:
-            self.events[key].insert(0, LockableEntry(expiry))
+            self.events[key][:0] = [LockableEntry(expiry) for _ in range(amount)]
 
             return True
 
@@ -118,7 +124,7 @@ class MemoryStorage(Storage, MovingWindowSupport):
         :param key: the key to get the expiry for
         """
 
-        return int(self.expirations.get(key, -1))
+        return int(self.expirations.get(key, time.time()))
 
     async def get_num_acquired(self, key: str, expiry: int) -> int:
         """
