@@ -5,8 +5,5 @@ errors and exceptions
 
 class ConfigurationError(Exception):
     """
-    exception raised when a configuration problem
-    is encountered
+    exception raised when a configuration problem is encountered
     """
-
-    pass
