@@ -15,7 +15,7 @@ class RedisSentinelStorage(RedisStorage):
     STORAGE_SCHEME = ["redis+sentinel"]
     """The storage scheme for redis accessed via a redis sentinel installation"""
 
-    DEFAULT_OPTIONS = {
+    DEFAULT_OPTIONS: Dict[str, Any] = {
         "socket_timeout": 0.2,
     }
     "Default options passed to :class:`~redis.sentinel.Sentinel`"
@@ -48,10 +48,12 @@ class RedisSentinelStorage(RedisStorage):
         sentinel_configuration = []
         sentinel_options = sentinel_kwargs.copy() if sentinel_kwargs else {}
 
+        parsed_auth = {}
+
         if parsed.username:
-            sentinel_options["username"] = parsed.username
+            parsed_auth["username"] = parsed.username
         if parsed.password:
-            sentinel_options["password"] = parsed.password
+            parsed_auth["password"] = parsed.password
 
         sep = parsed.netloc.find("@") + 1
 
@@ -67,8 +69,8 @@ class RedisSentinelStorage(RedisStorage):
 
         self.sentinel = self.dependencies["redis.sentinel"].Sentinel(
             sentinel_configuration,
-            sentinel_kwargs=sentinel_options,
-            **{**self.DEFAULT_OPTIONS, **options}
+            sentinel_kwargs={**parsed_auth, **sentinel_options},
+            **{**self.DEFAULT_OPTIONS, **parsed_auth, **options}
         )
         self.storage = self.sentinel.master_for(self.service_name)
         self.storage_slave = self.sentinel.slave_for(self.service_name)
