@@ -3,12 +3,12 @@
 """
 import re
 import sys
-from typing import Any
-from typing import List
-from typing import Type
+from typing import Any, Dict, List, Type
 
-from .limits import RateLimitItem
-from .limits import GRANULARITIES
+import pkg_resources
+
+from .errors import ConfigurationError
+from .limits import GRANULARITIES, RateLimitItem
 
 SEPARATORS = re.compile(r"[,;|]{1}")
 SINGLE_EXPR = re.compile(
@@ -27,22 +27,63 @@ EXPR = re.compile(
 )
 
 
+class LazyDependency:
+    """
+    Simple utility that provides an :attr:`dependency`
+    to the child class to fetch any dependencies
+    without having to import them explicitly.
+    """
+
+    DEPENDENCIES: List[str] = []
+    """
+    The python modules this class has a dependency on.
+    Used to lazily populate the :attr:`dependencies`
+    """
+
+    def __init__(self):
+        self._dependencies = {}
+
+    @property
+    def dependencies(self) -> Dict[str, Any]:
+        """
+        Cached mapping of the modules this storage depends on. This is done so that the module
+        is only imported lazily when the storage is instantiated.
+        """
+        if not getattr(self, "_dependencies", {}):
+            dependencies = {}
+            for name in self.DEPENDENCIES:
+                dependency = get_dependency(name)
+
+                if not dependency:
+                    raise ConfigurationError(
+                        f"{name} prerequisite not available"
+                    )  # pragma: no cover
+                dependencies[name] = dependency
+            self._dependencies = dependencies
+        return self._dependencies
+
+
 def get_dependency(dep) -> Any:
     """
-    safe function to import a module programmatically
+    safe function to import a module at runtime
     """
     try:
-        __import__(dep)
+        if dep not in sys.modules:
+            __import__(dep)
 
         return sys.modules[dep]
     except ImportError:  # pragma: no cover
         return None
 
 
+def get_package_data(path: str) -> bytes:
+    return pkg_resources.resource_string(__name__, path)
+
+
 def parse_many(limit_string: str) -> List[RateLimitItem]:
     """
     parses rate limits in string notation containing multiple rate limits
-    (e.g. '1/second; 5/minute')
+    (e.g. ``1/second; 5/minute``)
 
     :param limit_string: rate limit string using :ref:`ratelimit-string`
     :raise ValueError: if the string notation is invalid.
@@ -59,7 +100,9 @@ def parse_many(limit_string: str) -> List[RateLimitItem]:
         if match:
             amount, _, multiples, granularity_string = match.groups()
             granularity = granularity_from_string(granularity_string)
-            limits.append(granularity(int(amount), multiples and int(multiples) or None))
+            limits.append(
+                granularity(int(amount), multiples and int(multiples) or None)
+            )
 
     return limits
 
@@ -67,7 +110,7 @@ def parse_many(limit_string: str) -> List[RateLimitItem]:
 def parse(limit_string: str) -> RateLimitItem:
     """
     parses a single rate limit in string notation
-    (e.g. '1/second' or '1 per second'
+    (e.g. ``1/second`` or ``1 per second``)
 
     :param limit_string: rate limit string using :ref:`ratelimit-string`
     :raise ValueError: if the string notation is invalid.
